package com.sooka.system.mapper;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.enums.DataSourceType;
import com.sooka.system.domain.TgjjDbxx;

/**
 * 担保信息Mapper接口
 *
 * @author lei
 * @date 2021-11-16
 */
@DataSource(value = DataSourceType.SLAVE)
public interface TgjjDbxxMapper
{
    /**
     * 查询担保信息
     *
     * @param ID 担保信息ID
     * @return 担保信息
     */
    public TgjjDbxx selectTgjjDbxxById(Long ID);

    /**
     * 查询担保信息列表
     *
     * @param tgjjDbxx 担保信息
     * @return 担保信息集合
     */
    public List<TgjjDbxx> selectTgjjDbxxList(TgjjDbxx tgjjDbxx);

    /**
     * 新增担保信息
     *
     * @param tgjjDbxx 担保信息
     * @return 结果
     */
    public int insertTgjjDbxx(TgjjDbxx tgjjDbxx);

    /**
     * 修改担保信息
     *
     * @param tgjjDbxx 担保信息
     * @return 结果
     */
    public int updateTgjjDbxx(TgjjDbxx tgjjDbxx);

    /**
     * 删除担保信息
     *
     * @param ID 担保信息ID
     * @return 结果
     */
    public int deleteTgjjDbxxById(Long ID);

    /**
     * 批量删除担保信息
     *
     * @param IDs 需要删除的数据ID
     * @return 结果
     */
    public int deleteTgjjDbxxByIds(String[] IDs);
}
