package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjDbxx;
import com.sooka.system.service.ITgjjDbxxService;

/**
 * 担保信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/dbxx")
public class TgjjDbxxController extends BaseController
{
    private String prefix = "system/dbxx";

    @Autowired
    private ITgjjDbxxService tgjjDbxxService;

    @RequiresPermissions("system:dbxx:view")
    @GetMapping()
    public String dbxx()
    {
        return prefix + "/dbxx";
    }

    /**
     * 查询担保信息列表
     */
    @RequiresPermissions("system:dbxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjDbxx tgjjDbxx)
    {
        startPage();
        List<TgjjDbxx> list = tgjjDbxxService.selectTgjjDbxxList(tgjjDbxx);
        return getDataTable(list);
    }

    /**
     * 导出担保信息列表
     */
    @RequiresPermissions("system:dbxx:export")
    @Log(title = "担保信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjDbxx tgjjDbxx)
    {
        List<TgjjDbxx> list = tgjjDbxxService.selectTgjjDbxxList(tgjjDbxx);
        ExcelUtil<TgjjDbxx> util = new ExcelUtil<TgjjDbxx>(TgjjDbxx.class);
        return util.exportExcel(list, "dbxx");
    }

    /**
     * 新增担保信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存担保信息
     */
    @RequiresPermissions("system:dbxx:add")
    @Log(title = "担保信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjDbxx tgjjDbxx)
    {
        return toAjax(tgjjDbxxService.insertTgjjDbxx(tgjjDbxx));
    }

    /**
     * 修改担保信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjDbxx tgjjDbxx = tgjjDbxxService.selectTgjjDbxxById(ID);
        mmap.put("tgjjDbxx", tgjjDbxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存担保信息
     */
    @RequiresPermissions("system:dbxx:edit")
    @Log(title = "担保信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjDbxx tgjjDbxx)
    {
        return toAjax(tgjjDbxxService.updateTgjjDbxx(tgjjDbxx));
    }

    /**
     * 删除担保信息
     */
    @RequiresPermissions("system:dbxx:remove")
    @Log(title = "担保信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjDbxxService.deleteTgjjDbxxByIds(ids));
    }
}
